==> vue-cal-4.8.1.tgz: package/README.md <==
# vue-cal

[![Latest Version on NPM](https://img.shields.io/npm/v/vue-cal.svg)](https://npmjs.com/package/vue-cal)
[![Software License](https://img.shields.io/badge/license-MIT-brightgreen.svg)](LICENSE.md)
[![npm](https://img.shields.io/npm/dt/vue-cal.svg)](https://www.npmjs.com/package/vue-cal)
[![npm](https://img.shields.io/npm/dw/vue-cal.svg)](https://www.npmjs.com/package/vue-cal)
> A Vue JS full calendar, no dependency, no BS. :metal:

## Installation

```
npm i vue-cal
```

**Vue 2 (legacy)**

```
npm i vue-cal@legacy
```

___

## Demo & Documentation
> [antoniandre.github.io/vue-cal](https://antoniandre.github.io/vue-cal)

___

## Browser Support
![Chrome](https://raw.github.com/alrra/browser-logos/master/src/chrome/chrome_48x48.png) | ![Firefox](https://raw.github.com/alrra/browser-logos/master/src/firefox/firefox_48x48.png) | ![Safari](https://raw.github.com/alrra/browser-logos/master/src/safari/safari_48x48.png) | ![Opera](https://raw.github.com/alrra/browser-logos/master/src/opera/opera_48x48.png) | ![Edge](https://raw.github.com/alrra/browser-logos/master/src/edge/edge_48x48.png) | ![IE](https://raw.github.com/alrra/browser-logos/master/src/archive/internet-explorer_9-11/internet-explorer_9-11_48x48.png) |
--- | --- | --- | --- | --- | --- |
Latest ✔ | Latest ✔ | Latest ✔ | Latest ✔ | Latest ✔ | 10+ ✔ |

___

## Donating

If you want to support the development of this library, you can buy me a beer or [become a sponsor](https://github.com/sponsors/antoniandre)!

[![paypal](https://www.paypalobjects.com/en_AU/i/btn/btn_donateCC_LG.gif)](https://www.paypal.me/antoniandre1)
Thank you!

If you are using this library for profit business, please consider [backing me](https://github.com/sponsors/antoniandre)!
It ensures that the project your products rely on keep being actively maintained. :)

___

## Contributing

If you have any idea, feel free to open an issue to discuss a new feature or fork Vue Cal and submit your changes back to me.

___

## Release Notes

[antoniandre.github.io/vue-cal/#release-notes](https://antoniandre.github.io/vue-cal/#release-notes)

==> vue-cal-4.10.2.tgz: package/README.md <==
# Vue Cal v4
[![Latest Version on NPM](https://img.shields.io/npm/v/vue-cal.svg)](https://npmjs.com/package/vue-cal)
[![Software License](https://img.shields.io/badge/license-MIT-brightgreen.svg)](LICENSE.md)
[![npm](https://img.shields.io/npm/dt/vue-cal.svg)](https://www.npmjs.com/package/vue-cal)
[![npm](https://img.shields.io/npm/dw/vue-cal.svg)](https://www.npmjs.com/package/vue-cal)
[![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)
> A Vue JS full calendar, no dependency, no BS. :metal:

<br>

> [!WARNING]
> **VERSION 4.10.0 IS THE FINAL RELEASE IN THIS REPOSITORY AND IS NO LONGER ACTIVELY MAINTAINED. FOR THE LATEST DEVELOPMENTS AND V5, VISIT [Vue Cal V5](https://github.com/antoniandre/vue-cal)!**  🚀
> - For the latest stable v4.x.x, continue using this version.
> - To contribute to v5 or try the new features, head over to the [v5 repo](https://github.com/antoniandre/vue-cal).
<br>

## Installation

```
npm i vue-cal
```

**Vue 2 (legacy)**

```
npm i vue-cal@legacy
```

___

## Demo & Documentation
> [antoniandre.github.io/vue-cal-v4](https://antoniandre.github.io/vue-cal-v4)

___

## Browser Support
![Chrome](https://raw.github.com/alrra/browser-logos/master/src/chrome/chrome_48x48.png) | ![Firefox](https://raw.github.com/alrra/browser-logos/master/src/firefox/firefox_48x48.png) | ![Safari](https://raw.github.com/alrra/browser-logos/master/src/safari/safari_48x48.png) | ![Opera](https://raw.github.com/alrra/browser-logos/master/src/opera/opera_48x48.png) | ![Edge](https://raw.github.com/alrra/browser-logos/master/src/edge/edge_48x48.png) | ![IE](https://raw.github.com/alrra/browser-logos/master/src/archive/internet-explorer_9-11/internet-explorer_9-11_48x48.png) |
--- | --- | --- | --- | --- | --- |
Latest ✔ | Latest ✔ | Latest ✔ | Latest ✔ | Latest ✔ | 10+ ✔ |

___

## Donating

If you want to support the development of this library, you can buy me a beer or [become a sponsor](https://github.com/sponsors/antoniandre)!

[![paypal](https://www.paypalobjects.com/en_AU/i/btn/btn_donateCC_LG.gif)](https://www.paypal.me/antoniandre1)
Thank you!

If you are using this library for profit business, please consider [backing me](https://github.com/sponsors/antoniandre)!
It ensures that the project your products rely on keep being actively maintained. :)

___

## Contributing

If you have any idea, feel free to open an issue to discuss a new feature or fork Vue Cal and submit your changes back to me.

___

## Release Notes

[antoniandre.github.io/vue-cal-v4/#release-notes](https://antoniandre.github.io/vue-cal-v4/#release-notes)
